"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = require("../apis/logger");
exports.SHORT_DESCRIPTION = "Build OpenAPI specification from HAR.";
exports.HAR = {
    long: "har",
    required: true,
    description: {
        short: "har file path",
        long: `\tThe HTTP Archive format(HAR), is JSON formatted archive file format for logging of a web browswer's intraction with site.
        To generate the HAR file for your existion application use Chrome,Firefox,Safari,Internet Explorer,Edge.
        To generate the HAR file for new projects use Insomania REST Clint Desktop application.`
    }
};
exports.HOST = {
    short: "h",
    long: "host",
    required: false,
    description: {
        short: "Filter the http request from HAR and use it as server url in output.",
        long: "Host name is mandatore field to build openapi sepcification by default it will be first request url in HAR."
    }
};
exports.BASE_PATH = {
    short: "b",
    long: "base-path",
    required: true,
    description: {
        short: "Separate the common path as base path from HTTP requests. Example:['api/v1']",
        long: "\tBase path of the end point"
    },
    default: ""
};
exports.PATH_REGEX = {
    short: "r",
    long: "path-param-regex",
    required: false,
    description: {
        short: "Convert Regex matching params into dynamic path ",
        long: `\tIn request URL regex matching path parameter will be converted into ${logger_1.colors.Bright}${logger_1.colors.fg.Green}dynamic path parameters${logger_1.colors.Reset}.\n\tPassed value converted into Regular experssion by using ${logger_1.colors.Bright}${logger_1.colors.fg.Cyan}new RegExp()${logger_1.colors.Reset}(JavaScript)`
    },
    default: `${getDefault("[0-9]|[-$@!~%^*()_+]")}`
};
exports.SECURITY_HEADERS = {
    short: "s",
    long: "security-headers",
    required: false,
    description: {
        short: "Map matching HTTP headers into security headers on request.",
        long: `\tTo map custom security headers link 'x-api-key' as autorization header.

            ${getTitle("Syntax")}
                {
                    "${logger_1.colors.fg.Red}headerNameInHTTPRequest${logger_1.colors.Reset}": {Sequrity Scheme Object as per OAS3.0}
                }

            ${getTitle("Example")}
                {
                    "${logger_1.colors.fg.Green}x-api-key${logger_1.colors.Reset}": {
                        "name": "X-API-KEY,
                        "type": "apiKey",
                        "in": "headers"
                    }
                }
        `
    },
    default: `${getDefault("{}")}`
};
exports.TEMPLATE = {
    short: "t",
    long: "template",
    required: false,
    description: {
        short: "To override the default template pass the your template file location.",
        long: "\tYou can override the default template by passing your template file location."
    },
    default: `${getDefault("Avantation Template")}`
};
exports.DIABLE_TAG = {
    long: "disable-tag",
    required: false,
    description: {
        short: "Diable end points grouping based on route path in HAR"
    },
    default: `${getDefault("false")}`
};
exports.STATIC_UI_LOGO = {
    long: "static-ui-logo",
    required: false,
    description: {
        short: "Static-UI logo file location"
    }
};
exports.BUILD_STATIC_UI = {
    long: "build-static-ui",
    required: false,
    description: {
        short: "Build the static user interface from generated OpenAPI3.0 specification."
    },
    default: `${getDefault("false")}`
};
exports.HTTP_SNIPPET = {
    long: "http-snippet",
    required: false,
    description: {
        short: "Generate HTTP smaple code snippet for request and appedn it as 'x-code-sample' to OpenAPI path object."
    },
    default: `${getDefault("false")}`
};
exports._JSON = {
    short: "j",
    long: "json",
    description: {
        short: "Write output result in JSON format."
    },
    required: false,
    default: `${getDefault("false")}`
};
exports.PIPE = {
    short: "p",
    long: "pipe",
    description: {
        short: "Pipe the result into next command"
    },
    required: false,
    default: `${getDefault("false")}`
};
exports.OUT = {
    short: "o",
    long: "out",
    description: {
        short: "Write output result at this DEST location."
    },
    required: false,
    default: `${getDefault("./avantation.yaml")}`
};
exports.INFO = `
Avantion is command-line tool (avantation --help)
${exports.SHORT_DESCRIPTION}

${getTitle("Usages")}

  avantation [options]

Avantation will search HTTP requested and build the Request body,Query Parameter,Path Parameter Object based on host and base path pattern matching in har file and save the all the results on avantation.yaml

By default output file will be written on current working directory.To change the output file location use ${logger_1.colors.fg.Yellow}-o, --out${logger_1.colors.Reset}.

${getTitle("Example")}

${getExample()}

${getTitle("Options")}
`;
exports.manual = [
    exports.HAR,
    exports.HOST,
    exports.BASE_PATH,
    exports.PATH_REGEX,
    exports.SECURITY_HEADERS,
    exports.TEMPLATE,
    exports.DIABLE_TAG,
    exports.HTTP_SNIPPET,
    exports.BUILD_STATIC_UI,
    exports.STATIC_UI_LOGO,
    exports._JSON,
    exports.OUT
];
function getTitle(title) {
    return `${logger_1.colors.Bright}${logger_1.colors.fg.Magenta}${title}${logger_1.colors.Reset}`;
}
function getExample() {
    return `  ${logger_1.colors.fg.Green}avantation${logger_1.colors.Reset} ${logger_1.colors.fg.Yellow}--har${logger_1.colors.Reset} example.com.har ${logger_1.colors.fg.Yellow}-h${logger_1.colors.Reset} apis.example.com ${logger_1.colors.fg.Yellow}-b${logger_1.colors.Reset} v1 ${logger_1.colors.fg.Yellow}-o${logger_1.colors.Reset} ./example.json`;
}
function getDefault(defaut) {
    return `\t${logger_1.colors.Bright}${logger_1.colors.fg.Red}default:${logger_1.colors.Reset} ${logger_1.colors.Bright}${logger_1.colors.fg.White}${defaut}${logger_1.colors.Reset}`;
}
